@@ -7,25 +7,92 @@ from ..lazy.with_model_info_batch_op import WithModelInfoBatchOp
 from ..lazy.with_train_info import WithTrainInfo
 
 
-class TensorFlow2BatchOp(BatchOperator):
-    CLS_NAME = 'com.alibaba.alink.operator.batch.tensorflow.TensorFlow2BatchOp'
+class TFSavedModelPredictBatchOp(BatchOperator):
+    CLS_NAME = 'com.alibaba.alink.operator.batch.tensorflow.TFSavedModelPredictBatchOp'
     OP_TYPE = 'FUNCTION'
 
     def __init__(self, *args, **kwargs):
         kwargs['CLS_NAME'] = self.CLS_NAME
         kwargs['OP_TYPE'] = self.OP_TYPE
-        super(TensorFlow2BatchOp, self).__init__(*args, **kwargs)
+        super(TFSavedModelPredictBatchOp, self).__init__(*args, **kwargs)
+        pass
+
+    def setModelPath(self, val):
+        return self._add_param('modelPath', val)
+
+    def setOutputSchemaStr(self, val):
+        return self._add_param('outputSchemaStr', val)
+
+    def setGraphDefTag(self, val):
+        return self._add_param('graphDefTag', val)
+
+    def setInputSignatureDefs(self, val):
+        return self._add_param('inputSignatureDefs', val)
+
+    def setOutputSignatureDefs(self, val):
+        return self._add_param('outputSignatureDefs', val)
+
+    def setReservedCols(self, val):
+        return self._add_param('reservedCols', val)
+
+    def setSelectedCols(self, val):
+        return self._add_param('selectedCols', val)
+
+    def setSignatureDefKey(self, val):
+        return self._add_param('signatureDefKey', val)
+
+
+class TFTableModelPredictBatchOp(BatchOperator):
+    CLS_NAME = 'com.alibaba.alink.operator.batch.tensorflow.TFTableModelPredictBatchOp'
+    OP_TYPE = 'FUNCTION'
+
+    def __init__(self, *args, **kwargs):
+        kwargs['CLS_NAME'] = self.CLS_NAME
+        kwargs['OP_TYPE'] = self.OP_TYPE
+        super(TFTableModelPredictBatchOp, self).__init__(*args, **kwargs)
         pass
 
     def setOutputSchemaStr(self, val):
         return self._add_param('outputSchemaStr', val)
 
-    def setIntraOpParallelism(self, val):
-        return self._add_param('intraOpParallelism', val)
+    def setGraphDefTag(self, val):
+        return self._add_param('graphDefTag', val)
+
+    def setInputSignatureDefs(self, val):
+        return self._add_param('inputSignatureDefs', val)
+
+    def setOutputSignatureDefs(self, val):
+        return self._add_param('outputSignatureDefs', val)
+
+    def setReservedCols(self, val):
+        return self._add_param('reservedCols', val)
+
+    def setSelectedCols(self, val):
+        return self._add_param('selectedCols', val)
+
+    def setSignatureDefKey(self, val):
+        return self._add_param('signatureDefKey', val)
+
+
+class TFTableModelTrainBatchOp(BatchOperator):
+    CLS_NAME = 'com.alibaba.alink.operator.batch.tensorflow.TFTableModelTrainBatchOp'
+    OP_TYPE = 'FUNCTION'
+
+    def __init__(self, *args, **kwargs):
+        kwargs['CLS_NAME'] = self.CLS_NAME
+        kwargs['OP_TYPE'] = self.OP_TYPE
+        super(TFTableModelTrainBatchOp, self).__init__(*args, **kwargs)
+        pass
 
     def setMainScriptFile(self, val):
         return self._add_param('mainScriptFile', val)
 
+    def setUserFiles(self, val):
+        return self._add_param('userFiles', val)
+
+    def setIntraOpParallelism(self, val):
+        return self._add_param('intraOpParallelism', val)
+
     def setNumPSs(self, val):
         return self._add_param('numPSs', val)
 
@@ -38,9 +105,44 @@ class TensorFlow2BatchOp(BatchOperator):
     def setSelectedCols(self, val):
         return self._add_param('selectedCols', val)
 
+    def setUserParams(self, val):
+        return self._add_param('userParams', val)
+
+
+class TensorFlow2BatchOp(BatchOperator):
+    CLS_NAME = 'com.alibaba.alink.operator.batch.tensorflow.TensorFlow2BatchOp'
+    OP_TYPE = 'FUNCTION'
+
+    def __init__(self, *args, **kwargs):
+        kwargs['CLS_NAME'] = self.CLS_NAME
+        kwargs['OP_TYPE'] = self.OP_TYPE
+        super(TensorFlow2BatchOp, self).__init__(*args, **kwargs)
+        pass
+
+    def setMainScriptFile(self, val):
+        return self._add_param('mainScriptFile', val)
+
+    def setOutputSchemaStr(self, val):
+        return self._add_param('outputSchemaStr', val)
+
     def setUserFiles(self, val):
         return self._add_param('userFiles', val)
 
+    def setIntraOpParallelism(self, val):
+        return self._add_param('intraOpParallelism', val)
+
+    def setNumPSs(self, val):
+        return self._add_param('numPSs', val)
+
+    def setNumWorkers(self, val):
+        return self._add_param('numWorkers', val)
+
+    def setPythonEnv(self, val):
+        return self._add_param('pythonEnv', val)
+
+    def setSelectedCols(self, val):
+        return self._add_param('selectedCols', val)
+
     def setUserParams(self, val):
         return self._add_param('userParams', val)
 
@@ -55,15 +157,18 @@ class TensorFlowBatchOp(BatchOperator):
         super(TensorFlowBatchOp, self).__init__(*args, **kwargs)
         pass
 
+    def setMainScriptFile(self, val):
+        return self._add_param('mainScriptFile', val)
+
     def setOutputSchemaStr(self, val):
         return self._add_param('outputSchemaStr', val)
 
+    def setUserFiles(self, val):
+        return self._add_param('userFiles', val)
+
     def setIntraOpParallelism(self, val):
         return self._add_param('intraOpParallelism', val)
 
-    def setMainScriptFile(self, val):
-        return self._add_param('mainScriptFile', val)
-
     def setNumPSs(self, val):
         return self._add_param('numPSs', val)
 
@@ -76,9 +181,6 @@ class TensorFlowBatchOp(BatchOperator):
     def setSelectedCols(self, val):
         return self._add_param('selectedCols', val)
 
-    def setUserFiles(self, val):
-        return self._add_param('userFiles', val)
-
     def setUserParams(self, val):
         return self._add_param('userParams', val)
 
@@ -95,7 +197,7 @@ class TensorSerializeBatchOp(BatchOperator):
 
 
 class TensorToVectorBatchOp(BatchOperator):
-    CLS_NAME = 'com.alibaba.alink.operator.batch.dataproc.tensor.TensorToVectorBatchOp'
+    CLS_NAME = 'com.alibaba.alink.operator.batch.dataproc.TensorToVectorBatchOp'
     OP_TYPE = 'FUNCTION'
 
     def __init__(self, *args, **kwargs):
@@ -120,32 +222,6 @@ class TensorToVectorBatchOp(BatchOperator):
         return self._add_param('reservedCols', val)
 
 
-class TensorToVectorStreamOp(BatchOperator):
-    CLS_NAME = 'com.alibaba.alink.operator.stream.dataproc.tensor.TensorToVectorStreamOp'
-    OP_TYPE = 'FUNCTION'
-
-    def __init__(self, *args, **kwargs):
-        kwargs['CLS_NAME'] = self.CLS_NAME
-        kwargs['OP_TYPE'] = self.OP_TYPE
-        super(TensorToVectorStreamOp, self).__init__(*args, **kwargs)
-        pass
-
-    def setSelectedCol(self, val):
-        return self._add_param('selectedCol', val)
-
-    def setConvertMethod(self, val):
-        return self._add_param('convertMethod', val)
-
-    def setNumThreads(self, val):
-        return self._add_param('numThreads', val)
-
-    def setOutputCol(self, val):
-        return self._add_param('outputCol', val)
-
-    def setReservedCols(self, val):
-        return self._add_param('reservedCols', val)
-
-
 class TextApproxNearestNeighborPredictBatchOp(BatchOperator):
     CLS_NAME = 'com.alibaba.alink.operator.batch.similarity.TextApproxNearestNeighborPredictBatchOp'
     OP_TYPE = 'FUNCTION'
@@ -1218,55 +1294,3 @@ class VectorMinMaxScalerTrainBatchOp(BatchOperator, WithModelInfoBatchOp):
     def setMin(self, val):
         return self._add_param('min', val)
 
-
-class VectorNearestNeighborPredictBatchOp(BatchOperator):
-    CLS_NAME = 'com.alibaba.alink.operator.batch.similarity.VectorNearestNeighborPredictBatchOp'
-    OP_TYPE = 'FUNCTION'
-
-    def __init__(self, *args, **kwargs):
-        kwargs['CLS_NAME'] = self.CLS_NAME
-        kwargs['OP_TYPE'] = self.OP_TYPE
-        super(VectorNearestNeighborPredictBatchOp, self).__init__(*args, **kwargs)
-        pass
-
-    def setSelectedCol(self, val):
-        return self._add_param('selectedCol', val)
-
-    def setNumThreads(self, val):
-        return self._add_param('numThreads', val)
-
-    def setOutputCol(self, val):
-        return self._add_param('outputCol', val)
-
-    def setRadius(self, val):
-        return self._add_param('radius', val)
-
-    def setReservedCols(self, val):
-        return self._add_param('reservedCols', val)
-
-    def setTopN(self, val):
-        return self._add_param('topN', val)
-
-
-class VectorNearestNeighborTrainBatchOp(BatchOperator):
-    CLS_NAME = 'com.alibaba.alink.operator.batch.similarity.VectorNearestNeighborTrainBatchOp'
-    OP_TYPE = 'FUNCTION'
-
-    def __init__(self, *args, **kwargs):
-        kwargs['CLS_NAME'] = self.CLS_NAME
-        kwargs['OP_TYPE'] = self.OP_TYPE
-        super(VectorNearestNeighborTrainBatchOp, self).__init__(*args, **kwargs)
-        pass
-
-    def setIdCol(self, val):
-        return self._add_param('idCol', val)
-
-    def setSelectedCol(self, val):
-        return self._add_param('selectedCol', val)
-
-    def setTrainType(self, val):
-        return self._add_param('trainType', val)
-
-    def setMetric(self, val):
-        return self._add_param('metric', val)
-
