@@ -164,6 +164,11 @@ class BaseOperator(WithParams):
         coltypes = self._j_op.getColTypes()
         return [str(FlinkTypeConverter.getTypeString(i)) for i in coltypes]
 
+    def getSchemaStr(self):
+        col_names = self.getColNames()
+        col_types = self.getColTypes()
+        return ", ".join([k + " " + v for k, v in zip(col_names, col_types)])
+
 
 # TODO: remove this
 class SideOutputOperator(object):
