@@ -2,7 +2,7 @@ import collections
 import os
 from typing import Union
 
-from py4j.java_gateway import JavaGateway
+from py4j.java_gateway import JavaGateway, CallbackServerParameters
 
 from .common.types.conversion.type_converters import py_list_to_j_array
 from .common.utils.packages import is_flink_1_9
@@ -214,6 +214,17 @@ def usePyFlinkEnv(parallelism: int = None, flinkHome: str = None) -> MLEnv:
     import pyflink
     gateway = pyflink.java_gateway.get_gateway()
     pyflink.java_gateway.import_flink_view(gateway)
+
+    # In PyFlink 1.9 and 1.10, PyFlink doesn't start callback server.
+    # We start callback server manually.
+    success = gateway.start_callback_server(
+        callback_server_parameters=CallbackServerParameters(port=0, daemonize=True, daemonize_connections=True))
+    if success:
+        callback_server_port = gateway.get_callback_server().get_listening_port()
+        gateway.java_gateway_server.resetCallbackClient(
+            gateway.java_gateway_server.getCallbackClient().getAddress(),
+            callback_server_port)
+
     set_java_gateway(gateway)
 
     from pyflink.dataset import ExecutionEnvironment
