@@ -3,13 +3,13 @@ import collections
 import functools
 import inspect
 
-from ..common.utils.packages import has_pyflink
+from pyflink.table.types import DataType
 
-if has_pyflink():
-    from pyflink.table.types import DataType
+from ..common.utils.packages import is_flink_1_9
+
+if not is_flink_1_9():
     from pyflink.table.udf import UserDefinedFunction
 else:
-    from .data_type import DataType
     from .user_defined_function import UserDefinedFunction
 
 
